[Libreoffice-commits] core.git: sc/source
Johnny_M
klasse at partyheld.de
Mon Feb 12 10:14:55 UTC 2018
sc/source/filter/excel/excform.cxx | 20 ++++++++++----------
1 file changed, 10 insertions(+), 10 deletions(-)
New commits:
commit 980de246715c95b6961367baf409c270dab58bc0
Author: Johnny_M <klasse at partyheld.de>
Date: Sat Feb 10 13:49:55 2018 +0100
Translate German variable names
Fakt -> Factor in Excel filter (excform)
Change-Id: Id93e2722e4f40cf2916d2abb3684d3570b88fce3
Reviewed-on: https://gerrit.libreoffice.org/49531
Tested-by: Jenkins <ci at libreoffice.org>
Reviewed-by: Michael Stahl <mstahl at redhat.com>
diff --git a/sc/source/filter/excel/excform.cxx b/sc/source/filter/excel/excform.cxx
index aa1b71f2f546..499c315baf26 100644
--- a/sc/source/filter/excel/excform.cxx
+++ b/sc/source/filter/excel/excform.cxx
@@ -378,7 +378,7 @@ ConvErr ExcelToSc::Convert( const ScTokenArray*& pResult, XclImpStream& aIn, std
}
case 0x19: // Special Attribute [327 279]
{
- sal_uInt16 nData(0), nFakt(0);
+ sal_uInt16 nData(0), nFactor(0);
sal_uInt8 nOpt(0);
nOpt = aIn.ReaduInt8();
@@ -386,19 +386,19 @@ ConvErr ExcelToSc::Convert( const ScTokenArray*& pResult, XclImpStream& aIn, std
if( meBiff == EXC_BIFF2 )
{
nData = aIn.ReaduInt8();
- nFakt = 1;
+ nFactor = 1;
}
else
{
nData = aIn.ReaduInt16();
- nFakt = 2;
+ nFactor = 2;
}
if( nOpt & 0x04 )
{
- // nFakt -> skip bytes or words AttrChoose
+ // nFactor -> skip bytes or words AttrChoose
++nData;
- aIn.Ignore(static_cast<std::size_t>(nData) * nFakt);
+ aIn.Ignore(static_cast<std::size_t>(nData) * nFactor);
}
else if( nOpt & 0x10 ) // AttrSum
DoMulArgs( ocSum, 1 );
@@ -970,7 +970,7 @@ ConvErr ExcelToSc::Convert( ScRangeListTabs& rRangeList, XclImpStream& aIn, std:
break;
case 0x19: // Special Attribute [327 279]
{
- sal_uInt16 nData(0), nFakt(0);
+ sal_uInt16 nData(0), nFactor(0);
sal_uInt8 nOpt(0);
nOpt = aIn.ReaduInt8();
@@ -978,19 +978,19 @@ ConvErr ExcelToSc::Convert( ScRangeListTabs& rRangeList, XclImpStream& aIn, std:
if( meBiff == EXC_BIFF2 )
{
nData = aIn.ReaduInt8();
- nFakt = 1;
+ nFactor = 1;
}
else
{
nData = aIn.ReaduInt16();
- nFakt = 2;
+ nFactor = 2;
}
if( nOpt & 0x04 )
{
- // nFakt -> skip bytes or words AttrChoose
+ // nFactor -> skip bytes or words AttrChoose
++nData;
- aIn.Ignore(static_cast<std::size_t>(nData) * nFakt);
+ aIn.Ignore(static_cast<std::size_t>(nData) * nFactor);
}
}
break;
More information about the Libreoffice-commits
mailing list